==> gnue-common_0.5.4.1.orig.tar.gz: gnue-common-0.5.4.1/src/datasources/drivers/mysql/mysql/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2004 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("MySQLdb")
url = "http://sourceforge.net/projects/mysql-python"
doc = """
Description
-----------
Mysql-python, written by Andy Dustman, supports MySQL 3.22, 3.23, and
4.x.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP (Installer available)

Connection Properties
----------------------
* host       -- This is the host for your connection (required)
* dbname     -- This is the name of the database to use (required)

Examples
--------
 [myconn]
 provider=mysql          # Use the MySQLdb adapter
 host=localhost          # The hostname/IP of the MySQL host
 dbname=mydb             # The name of the MySQL database

Notes
-----
1. Transactions are supported if MySQL is compiled with proper
   transactional support (3.x series does NOT do this by default!)

2. This driver has been partially tested.  If you are successfully using
   this driver, please let us know.

3. Windows installer available at http://www.cs.fhm.edu/~ifw00065/
"""

==> gnue-common_0.5.14.orig.tar.gz: gnue-common-0.5.14/src/datasources/drivers/mysql/mysql/Info.py <==
#
# This file is part of GNU Enterprise.
#
# GNU Enterprise is free software; you can redistribute it
# and/or modify it under the terms of the GNU General Public
# License as published by the Free Software Foundation; either
# version 2, or(at your option) any later version.
#
# GNU Enterprise is distributed in the hope that it will be
# useful, but WITHOUT ANY WARRANTY; without even the implied
# warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
# PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public
# License along with program; see the file COPYING. If not,
# write to the Free Software Foundation, Inc., 59 Temple Place
# - Suite 330, Boston, MA 02111-1307, USA.
#
# Copyright 2000-2005 Free Software Foundation
#
"""
Information on this driver
"""

#
# Notes on this driver
#
name = _("MySQLdb")
url = "http://sourceforge.net/projects/mysql-python"
doc = """
Description
-----------
Mysql-python, written by Andy Dustman, supports MySQL 3.22, 3.23, and
4.x.

Support
-------
Supported Platforms:

  - Linux/BSD
  - Solaris
  - MS Windows 98/NT/2000/XP (Installer available)

Connection Properties
----------------------
* host       -- This is the host for your connection (required)
* dbname     -- This is the name of the database to use (required)

Examples
--------
 [myconn]
 provider=mysql          # Use the MySQLdb adapter
 host=localhost          # The hostname/IP of the MySQL host
 dbname=mydb             # The name of the MySQL database

Notes
-----
1. Transactions are supported if MySQL is compiled with proper
   transactional support (3.x series does NOT do this by default!).

2. Windows installer available at http://www.cs.fhm.edu/~ifw00065/.

3. Other than that, the driver is fully functional with no known serious
   problems.
"""
